summaryrefslogtreecommitdiffstats
path: root/ksysv/ksvlookandfeel.cpp
diff options
context:
space:
mode:
authortpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2011-06-18 20:34:22 +0000
committertpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2011-06-18 20:34:22 +0000
commitb09bffed6b43262948018dfb0f11890850ddf7c1 (patch)
tree138696bfcc7ac01070d0e8ecaa1cdf94611a2bd8 /ksysv/ksvlookandfeel.cpp
parent6d43944a7130b9d1b4ae3fba37b774aced8612cf (diff)
downloadtdeadmin-b09bffed6b43262948018dfb0f11890850ddf7c1.tar.gz
tdeadmin-b09bffed6b43262948018dfb0f11890850ddf7c1.zip
TQt4 port kdeadmin
This enables compilation under both Qt3 and Qt4 git-svn-id: svn://anonsvn.kde.org/home/kde/branches/trinity/kdeadmin@1237416 283d02a7-25f6-0310-bc7c-ecb5cbfe19da
Diffstat (limited to 'ksysv/ksvlookandfeel.cpp')
-rw-r--r--ksysv/ksvlookandfeel.cpp8
1 files changed, 4 insertions, 4 deletions
diff --git a/ksysv/ksvlookandfeel.cpp b/ksysv/ksvlookandfeel.cpp
index 0e0fa58..c63c49d 100644
--- a/ksysv/ksvlookandfeel.cpp
+++ b/ksysv/ksvlookandfeel.cpp
@@ -32,11 +32,11 @@
#include <kfontdialog.h>
/*
* Constructs a KSVLookAndFeel which is a child of 'parent', with the
* name 'name' and widget flags set to 'f'
*/
-KSVLookAndFeel::KSVLookAndFeel( TQWidget* parent, const char* name, WFlags fl )
- : LookAndFeel( parent, name, fl )
+KSVLookAndFeel::KSVLookAndFeel( TQWidget* tqparent, const char* name, WFlags fl )
+ : LookAndFeel( tqparent, name, fl )
{
mTopLayout->setSpacing (KDialog::spacingHint());
mColorGrid->setSpacing (KDialog::spacingHint());
@@ -47,7 +47,7 @@ KSVLookAndFeel::KSVLookAndFeel( TQWidget* parent, const char* name, WFlags fl )
*/
KSVLookAndFeel::~KSVLookAndFeel()
{
- // no need to delete child widgets, Qt does it all for us
+ // no need to delete child widgets, TQt does it all for us
}
/*
@@ -32,11 +32,11 @@
#include <kfontdialog.h>
/*
- * Constructs a KSVLookAndFeel which is a child of 'parent', with the
+ * Constructs a KSVLookAndFeel which is a child of 'tqparent', with the
* name 'name' and widget flags set to 'f'
*/